local _,stash = ...
local L = stash.localization
local settings = stash.settings
_stash = stash -- for global reference and debugging

stash.main = CreateFrame("Frame")
stash.main:RegisterEvent("PLAYER_LOGIN")
stash.main:SetScript("OnEvent",function(self,event,...)
    if self[event] then
        self[event](self,...)
    end
end)

-- login initialization
function stash.main:PLAYER_LOGIN()
    stash.saved = StashSaved -- savedvar for all items across all characters
    self:CreateCharacter()
    -- at one point, filters were going to be remembered across sessions; keeping them a savedvar in case that happens
    settings.FilterRealm = false
    settings.FilterCharacter = false
    settings.FilterLocation = false
    settings.FilterType = false
    settings.FilterSubType = false
    settings.FilterEquipSlot = false
    -- finish setting up panels and stuff on login
    stash.frame:Setup()
    stash.itemsPanel:Setup()
    stash.filterPanel:Setup()
    stash.moneyPanel:Setup()
    stash.settingsPanel:Setup()
    stash.confirmPanel:Setup()
    stash.minimapButton:Setup()
    stash.tracking:Setup()

    local ldb = LibStub and LibStub.GetLibrary and LibStub:GetLibrary("LibDataBroker-1.1",true)
    if ldb then
        ldb:NewDataObject("Stash",{type="launcher", icon="Interface\\Icons\\INV_Misc_Bag_07", tooltiptext=L["Stash"], OnClick=stash.frame.Toggle }) 
    end

    SLASH_STASH1 = "/stash"
    SlashCmdList["STASH"] = stash.frame.Toggle

end

-- this creates a character in StashSaved--if needed--for the currently-logged in player to track their stuff
-- and also sets stash.current to point to the stash of the currently-logged-in player (mostly for tracking updates)
function stash.main:CreateCharacter()
    local realm = GetRealmName()
    local player = GetUnitName("player")
    if not stash.saved[realm] then
        stash.saved[realm] = {}
    end
    if not stash.saved[realm][player] then
        stash.saved[realm][player] = {
            realm = realm,
            player = player,
            money = 0,
            worn = {},
            bags = {[0]={},[1]={},[2]={},[3]={},[4]={}},
            bank = {[-1]={},[5]={},[6]={},[7]={},[8]={},[9]={},[10]={},[11]={}},
            reagents = {[-3]={}},
            void = {{},{}},
            mail = {},
            currency = {}
        }
    end
    stash.current = stash.saved[realm][player] -- all item tracking is done on current character's stash only
    stash.current.update = date("%x") -- log current date as last day character was updated
    stash.current.faction = UnitFactionGroup("player") -- log faction/race/gender that could potentially change
    stash.current.race = select(3,UnitRace("player"))
    stash.current.gender = UnitSex("player")
end

